Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(831)

Unified Diff: media/base/key_systems.h

Issue 1727833005: EME: Remove reference to "concrete" key systems. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@parent
Patch Set: rebase Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | media/base/key_systems.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/base/key_systems.h
diff --git a/media/base/key_systems.h b/media/base/key_systems.h
index 1c9f8cc101570d72fe585b32aabd16939aa93999..92c15d899ad5a77ab55398b4f76d1b32c0cb771b 100644
--- a/media/base/key_systems.h
+++ b/media/base/key_systems.h
@@ -80,14 +80,13 @@ MEDIA_EXPORT bool IsSupportedKeySystemWithInitDataType(
// Returns a name for |key_system| suitable to UMA logging.
MEDIA_EXPORT std::string GetKeySystemNameForUMA(const std::string& key_system);
-// Returns whether AesDecryptor can be used for the given |concrete_key_system|.
-MEDIA_EXPORT bool CanUseAesDecryptor(const std::string& concrete_key_system);
+// Returns whether AesDecryptor can be used for the given |key_system|.
+MEDIA_EXPORT bool CanUseAesDecryptor(const std::string& key_system);
#if defined(ENABLE_PEPPER_CDMS)
-// Returns the Pepper MIME type for |concrete_key_system|.
-// Returns empty string if |concrete_key_system| is unknown or not Pepper-based.
-MEDIA_EXPORT std::string GetPepperType(
- const std::string& concrete_key_system);
+// Returns the Pepper MIME type for |key_system|.
+// Returns empty string if |key_system| is unknown or not Pepper-based.
+MEDIA_EXPORT std::string GetPepperType(const std::string& key_system);
#endif
#if defined(UNIT_TEST)
« no previous file with comments | « no previous file | media/base/key_systems.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698